@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,15 +23,13 @@
 using namespace KAddressBookGrantlee;
 
 ContactGrantleeWebSite::ContactGrantleeWebSite(const KContacts::ResourceLocatorUrl &resourceLocator, QObject *parent)
-    : QObject(parent),
-      mResourceLocator(resourceLocator)
+    : QObject(parent)
+    , mResourceLocator(resourceLocator)
 {
-
 }
 
 ContactGrantleeWebSite::~ContactGrantleeWebSite()
 {
-
 }
 
 QString ContactGrantleeWebSite::url() const
@@ -43,5 +41,5 @@ bool ContactGrantleeWebSite::preferred() const
 {
     const QStringList value = mResourceLocator.parameters().value(QStringLiteral("type"));
     //Validate PREF and pref
-    return value.contains(QStringLiteral("pref"), Qt::CaseInsensitive);
+    return value.contains(QLatin1String("pref"), Qt::CaseInsensitive);
 }
