@@ -91,13 +91,13 @@ public:
     }
 
     QVector<QObject *> mObjects;
-    Grantlee::Engine *mEngine;
+    Grantlee::Engine *mEngine = nullptr;
     QSharedPointer<Grantlee::FileSystemTemplateLoader> mTemplateLoader;
     Grantlee::Template mSelfcontainedTemplate;
     Grantlee::Template mEmbeddableTemplate;
     QString mErrorMessage;
-    bool forceDisableQRCode;
-    bool showQRCode;
+    bool forceDisableQRCode = false;
+    bool showQRCode = false;
 };
 
 GrantleeContactFormatter::GrantleeContactFormatter()
@@ -314,6 +314,7 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     QVariantList phoneNumbers;
     int counter = 0;
     const KContacts::PhoneNumber::List lstPhone = rawContact.phoneNumbers();
+    phoneNumbers.reserve(lstPhone.count());
     for (const KContacts::PhoneNumber &phoneNumber : lstPhone) {
         phoneNumbers.append(phoneNumberHash(phoneNumber, counter));
         counter++;
@@ -325,7 +326,7 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     QVariantList imAddresses;
     const QStringList customs = rawContact.customs();
     for (const QString &custom : customs) {
-        if (custom.startsWith(QStringLiteral("messaging/"))) {
+        if (custom.startsWith(QLatin1String("messaging/"))) {
             int pos = custom.indexOf(QLatin1Char(':'));
             QString key = custom.left(pos);
             key.remove(QStringLiteral("-All"));
@@ -342,8 +343,8 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     const KContacts::ResourceLocatorUrl::List extraUrlList = rawContact.extraUrlList();
     for (const KContacts::ResourceLocatorUrl &resourceLocator : extraUrlList) {
         QString url = resourceLocator.url().url();
-        if (!url.startsWith(QStringLiteral("http://"))
-            && !url.startsWith(QStringLiteral("https://"))) {
+        if (!url.startsWith(QLatin1String("http://"))
+            && !url.startsWith(QLatin1String("https://"))) {
             url = QStringLiteral("http://") + url;
         }
         websites.append(KStringHandler::tagUrls(url));
@@ -373,6 +374,7 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     QVariantList addresses;
     counter = 0;
     const KContacts::Address::List lstAddresses = rawContact.addresses();
+    addresses.reserve(lstAddresses.count());
     for (const KContacts::Address &address : lstAddresses) {
         addresses.append(addressHash(address, counter));
         counter++;
@@ -465,7 +467,7 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
 
     if (!customs.empty()) {
         for (QString custom : qAsConst(customs)) {   //krazy:exclude=foreach
-            if (custom.startsWith(QStringLiteral("KADDRESSBOOK-"))) {
+            if (custom.startsWith(QLatin1String("KADDRESSBOOK-"))) {
                 custom.remove(QStringLiteral("KADDRESSBOOK-X-"));
                 custom.remove(QStringLiteral("KADDRESSBOOK-"));
 
@@ -521,13 +523,11 @@ QString GrantleeContactFormatter::toHtml(HtmlForm form) const
     contactObject.insert(QStringLiteral("customFields"), customFields);
     contactObject.insert(QStringLiteral("customFieldsUrl"), customFieldsUrl);
 
-#if defined(HAVE_PRISON)
     if (!d->forceDisableQRCode) {
         if (d->showQRCode) {
             contactObject.insert(QStringLiteral("hasqrcode"), QStringLiteral("true"));
         }
     }
-#endif
 
     QVariantHash colorsObject;
 
