@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,8 +31,8 @@ using namespace SendLater;
 SendLaterTimeDateWidget::SendLaterTimeDateWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout(this);
-    lay->setMargin(0);
+    QHBoxLayout *lay = new QHBoxLayout;
+    lay->setContentsMargins(0, 0, 0, 0);
 
     QDateTime t = QDateTime::currentDateTime();
     t = t.addSecs(60 * 60);
@@ -49,6 +49,8 @@ SendLaterTimeDateWidget::SendLaterTimeDateWidget(QWidget *parent)
 
     lay->addWidget(mDateComboBox);
     lay->addWidget(mTimeComboBox);
+
+    setLayout(lay);
 }
 
 SendLaterTimeDateWidget::~SendLaterTimeDateWidget()
